""" Tim related sub-routines

    Copyright (2019) SCS Team.
    contributions preferrably comply with pep8 code structure 
    guidelines.
"""

import logging

import xarray as xr

from .xgm import matchXgmTimPulseId
from ..constants import mnemonics as _mnemonics



log = logging.getLogger(__name__)


def load_TIM(run, apd='MCP2apd'):
    """
    Load TIM traces and match them to SASE3 pulses.

    Parameters
    ----------
    run: extra_data.DataCollection, extra_data.RunDirectory

    Returns
    -------
    timdata : xarray.DataArray
        xarray DataArray containing the tim data

    Example
    -------
    >>> import toolbox_scs as tb
    >>> import toolbox_scs.detectors as tbdet
    >>> run = tb.run_by_proposal(2212, 235)
    >>> data = tbdet.load_TIM(run)
    """
    
    fields = ["sase1", "sase3", "npulses_sase3", 
              "npulses_sase1", apd, "SCS_SA3", "nrj"]
    timdata = xr.Dataset()
    
    for f in fields:
        m = _mnemonics[f]
        timdata[f] = run.get_array(m['source'],
                                   m['key'], 
                                   extra_dims=m['dim'])

    timdata.attrs['run'] = run
    timdata = matchXgmTimPulseId(timdata)
    
    return timdata.rename({'sa3_pId': 'pulse'})[apd]